#ifndef NT2_INCLUDE_CONSTANTS_EXP_1_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EXP_1_HPP_INCLUDED

#include <nt2/exponential/include/constants/exp_1.hpp>

#endif
